(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     97409,       2376]
NotebookOptionsPosition[     49185,       1408]
NotebookOutlinePosition[     85676,       2201]
CellTagsIndexPosition[     85563,       2195]
WindowTitle->Statistics: Descriptive and Exploratory
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"7bbb7a7c-0171-40a9-97fb-721bb3b1018f"],

Cell["\<\
Statistics: Descriptive and Exploratory
\
\>", "Title",
 CellChangeTimes->{{3.520677779770745*^9, 3.5206777856383314`*^9}, {
  3.5372020290709085`*^9, 3.53720203957388*^9}, {3.537701321159156*^9, 
  3.537701351630069*^9}, {3.53772867232849*^9, 
  3.537728698850793*^9}},ExpressionUUID->"902b3e54-4904-48d6-a79c-\
b23ffc4007fb"],

Cell["\<\
Darren Glosemeyer & Harry Calkins
Wolfram Research
training@wolfram.com\
\>", "Subsubtitle",
 CellChangeTimes->{{3.520677813734141*^9, 3.520677823088076*^9}, {
  3.520687372999189*^9, 3.520687386262189*^9}, {3.5372020548140244`*^9, 
  3.537202058741335*^9}, {3.537202120722994*^9, 3.5372021251081343`*^9}, {
  3.537202351154377*^9, 
  3.537202382539572*^9}},ExpressionUUID->"5d034da4-9c57-4d6c-b752-\
85b2da6242d3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"9d3dd028-0f1c-446d-bc3b-32e6c2931ca6"],

Cell[CellGroupData[{

Cell["Descriptive Statistics", "Section",
 CellChangeTimes->{
  3.5364986505892925`*^9},ExpressionUUID->"48dd37a3-25db-46d0-b4b3-\
027cf5ac859b"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides numerous functions for describing and visualizing properties of \
data. Location, scale, and other shape statistics can be useful in \
understanding the underlying nature of a dataset, the population it was \
sampled from, or some group within that data or population. Measures for \
multivariate data can provide information about relationships between \
variables in the data or underlying population. Charts and plots can help to \
see those properties and relationships."
}], "Text",
 CellChangeTimes->{{3.5364987294771805`*^9, 3.5364988503652687`*^9}, {
   3.5365014536915894`*^9, 3.5365014595091705`*^9}, {3.536502027376952*^9, 
   3.5365022003144007`*^9}, {3.536502244319401*^9, 3.5365022724504004`*^9}, 
   3.537701369107442*^9, 
   3.5377298868946867`*^9},ExpressionUUID->"19e5e05c-4789-4621-a2cf-\
bea01a290674"],

Cell["", "Spacer",ExpressionUUID->"97ebb87d-adaa-43fa-8398-6d6d97f68d8a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"da745353-0285-4251-b99a-c0e3c16d37c5"],

Cell[CellGroupData[{

Cell["Accessing Data", "Section",
 CellChangeTimes->{{3.5364960777030206`*^9, 
  3.536496102079458*^9}},ExpressionUUID->"7fb390d5-19bd-4c5d-b236-\
ce1ec711fd5c"],

Cell["\<\
Data that is to be analyzed often needs to be obtained from some external \
source.\
\>", "Text",ExpressionUUID->"640d022e-deff-4b27-93a4-8cf21a708f89"],

Cell["", "Spacer",ExpressionUUID->"58523f17-7726-4c25-890c-c363d71c0109"],

Cell[CellGroupData[{

Cell["File Import/Export", "Subsubsection",
 CellChangeTimes->{{3.537701404129684*^9, 
  3.5377014088164387`*^9}},ExpressionUUID->"91ea43bf-4d28-4715-8575-\
fa5a9eac06b6"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox["Import",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Import"]], "InlineFormula",ExpressionUUID->
  "f8cbb9b8-63d4-44d0-aa9f-f56ca4b267d8"],
 " and ",
 Cell[BoxData[
  ButtonBox["Export",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Export"]], "InlineFormula",ExpressionUUID->
  "4aecc808-964c-4f81-b0be-8d367fd15683"],
 " functions can import or export dozens of different file formats, including \
numeric and tabular formats, plain or formatted text, and graphics formats."
}], "Text",
 CellChangeTimes->{
  3.5377014230194073`*^9},ExpressionUUID->"67347638-c377-40f5-b0fd-\
759034df9cb1"],

Cell[TextData[{
 "A few formats of particular note for numeric data analysis include ",
 Cell[BoxData[
  ButtonBox["XLS",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/XLS"]], "InlineFormula",ExpressionUUID->
  "cb117ec7-34e5-430b-bedf-c39ecc981d2b"],
 ", ",
 Cell[BoxData[
  ButtonBox["XLSX",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/XLSX"]], "InlineFormula",ExpressionUUID->
  "71116baf-40c3-4141-8957-6885924436dd"],
 ", ",
 Cell[BoxData[
  ButtonBox["CSV",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/CSV"]], "InlineFormula",ExpressionUUID->
  "7ffed077-ffcc-43e8-aaa7-22f7c9fb0af6"],
 ", ",
 Cell[BoxData[
  ButtonBox["TSV",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/TSV"]], "InlineFormula",ExpressionUUID->
  "403a730c-d918-4a1c-aba1-e737ead24987"],
 ", ",
 Cell[BoxData[
  ButtonBox["DBF",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/DBF"]], "InlineFormula",ExpressionUUID->
  "912ed9d4-92e7-455d-ba88-561577d3845c"],
 ", and ",
 Cell[BoxData[
  ButtonBox["MDB",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/format/MDB"]], "InlineFormula",ExpressionUUID->
  "70f3f00b-6fb4-4188-bb90-224abf9267ab"],
 ", but there are many others as well."
}], "Text",
 CellChangeTimes->{{3.435066632614512*^9, 3.4350666405364885`*^9}, {
   3.498291602483389*^9, 3.498291638536179*^9}, 
   3.498291721559744*^9},ExpressionUUID->"6e3845d1-e09d-411c-90e3-\
ef689efb0107"],

Cell[TextData[{
 "Available formats can be displayed by evaluating ",
 Cell[BoxData[
  ButtonBox["$ImportFormats",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/$ImportFormats"]], "InlineFormula",ExpressionUUID->
  "c484648f-5dd4-4d32-a98b-fccd568c49cc"],
 " and ",
 Cell[BoxData[
  ButtonBox["$ExportFormats",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/$ExportFormats"]], "InlineFormula",ExpressionUUID->
  "19a976ab-abff-401d-839b-be4dd50ad056"],
 "."
}], "MathCaption",ExpressionUUID->"69ab8571-ca44-471e-93a7-7404774bfeda"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"$ImportFormats", "//", "Length"}], ",", 
   RowBox[{"$ExportFormats", "//", "Length"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.4350665175976458`*^9, 3.43506652928522*^9}, {
  3.4350666503334885`*^9, 
  3.435066656302315*^9}},ExpressionUUID->"c17d46ac-4318-4e49-a228-\
b719b0b93de1"],

Cell["", "Spacer",ExpressionUUID->"7ed7cfe1-aab4-40bf-a84a-46c3facfd2ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Databases", "Subsubsection",ExpressionUUID->"8e0a8fcf-0e15-4a89-b8ab-f3ec6e428fad"],

Cell[TextData[{
 StyleBox[ButtonBox["DatabaseLink",
  BaseStyle->"Link",
  ButtonData->"paclet:DatabaseLink/tutorial/Overview"],
  FontSlant->"Italic"],
 ", included in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", allows users to integrate ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " with database management systems.  ",
 StyleBox["DatabaseLink",
  FontSlant->"Italic"],
 " is JDBC-compliant and works with all known databases.  It contains both an \
SQL and a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " interface."
}], "Text",
 CellChangeTimes->{{3.498291847629306*^9, 3.498291894956132*^9}, 
   3.537701467585497*^9},ExpressionUUID->"ad94b782-c7bc-4892-a3ad-\
7d425f3a708e"],

Cell["", "Spacer",ExpressionUUID->"805c74b0-311d-4c02-a493-07f79a3cf5b5"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"dce59320-bb66-4638-af68-f62f153f8038"],

Cell[CellGroupData[{

Cell["Descriptive Statistics", "Section",ExpressionUUID->"bc74e9d2-6692-401f-a846-4a1935d66117"],

Cell[TextData[{
 "Many descriptive statistics and charts are included in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " for data and distributions. We will see a small sampling of them in \
examples."
}], "Text",
 CellChangeTimes->{{3.434109838362525*^9, 3.4341098763781495`*^9}, {
  3.4976272205464683`*^9, 3.4976272477348385`*^9}, {3.497704568278659*^9, 
  3.497704573263193*^9}, {3.4977053983950853`*^9, 3.4977054111928616`*^9}, {
  3.536496185077757*^9, 
  3.536496190475297*^9}},ExpressionUUID->"eac96ee6-b4de-4455-9613-\
a794b5a5fc41"],

Cell["\<\
The built\[Hyphen]in Old Faithful geyser data includes durations and waiting \
times for geyser eruptions.\
\>", "MathCaption",ExpressionUUID->"cc156231-1c54-4994-9da5-e6cc0927083e"],

Cell[BoxData[
 RowBox[{"headers", "=", 
  RowBox[{"ExampleData", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<Statistics\>\"", ",", "\"\<OldFaithful\>\""}], "}"}], ",", 
    "\"\<ColumnHeadings\>\""}], "]"}]}]], "Input",ExpressionUUID->"efb2e7c5-\
4d6b-464d-9779-1b568b16f867"],

Cell[TextData[{
 "This gives descriptive measures based on the first 4 moments, as well as \
the median and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "th"], TraditionalForm]],ExpressionUUID->
  "dd5d51cf-7084-42ec-81a4-a702517f919b"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["90", "th"], TraditionalForm]],ExpressionUUID->
  "d1726a3c-7e76-4b08-82ad-57077791289e"],
 " percentiles for waiting durations."
}], "MathCaption",
 CellChangeTimes->{{3.497705549937003*^9, 3.4977055769857826`*^9}, {
   3.497706031889305*^9, 3.4977060477964363`*^9}, 
   3.4977093701475544`*^9},ExpressionUUID->"e2d4e11b-2ae3-46bd-a489-\
2353c7aac759"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ofdata", "=", 
   RowBox[{"ExampleData", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<Statistics\>\"", ",", "\"\<OldFaithful\>\""}], "}"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"ofdata", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
      "Mean", ",", "Variance", ",", "Skewness", ",", "Kurtosis", ",", 
       "Median", ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".1"}], "]"}], "&"}], ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".9"}], "]"}], "&"}]}], "}"}]}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.497705451758217*^9, 3.4977055348265643`*^9}, {
  3.4977059668543096`*^9, 3.4977060106380816`*^9}, {3.4977093769134393`*^9, 
  3.4977093830386744`*^9}},ExpressionUUID->"1f15dca5-9615-4746-8358-\
d1fea3eaf827"],

Cell["", "Spacer",ExpressionUUID->"7b32e463-b125-41a2-bc92-b8c3c0415ae8"],

Cell["\<\
Numerous visualization functions are included, allowing for various types of \
graphical interpretation of the data. \
\>", "Text",
 CellChangeTimes->{{3.497706305038204*^9, 3.497706345552533*^9}, 
   3.4979762551853647`*^9, {3.531666210611205*^9, 
   3.531666233340478*^9}},ExpressionUUID->"a3360e80-2f43-4f94-8cde-\
fb8c65950d98"],

Cell["\<\
The following visualizes the distributions of the data as histograms, box\
\[Hyphen]whisker plots, and violin plots.\
\>", "MathCaption",ExpressionUUID->"2c29923b-6f2e-4ccb-8be9-5662b0648912"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{
      RowBox[{"ofdata", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "i"}], "]"}], "]"}], ",", 
      RowBox[{"PlotLabel", "\[Rule]", 
       RowBox[{"headers", "[", 
        RowBox[{"[", "i", "]"}], "]"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{
       "Histogram", ",", "BoxWhiskerChart", ",", "DistributionChart"}], 
       "}"}]}], "}"}]}], "]"}], "//", "Grid"}]], "Input",
 CellChangeTimes->{{3.4977049492022123`*^9, 3.4977049523898954`*^9}, {
   3.497705075211609*^9, 3.497705078868186*^9}, 3.4977057903746395`*^9, {
   3.49770595835382*^9, 
   3.4977059739015903`*^9}},ExpressionUUID->"290348f2-e20e-43f2-ada4-\
1643f2d31667"],

Cell["", "Spacer",ExpressionUUID->"5ab6379e-f5ac-40f2-9bc6-b1c8a35b7af2"],

Cell[TextData[{
 "A gallery of statistical visualization functions with links to more \
detailed examples can be found on the",
 ButtonBox[" Statistical Visualization guide page",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/StatisticalVisualization"],
 "."
}], "Text",
 CellDingbat->
  "\[LightBulb]",ExpressionUUID->"244797de-55a7-4098-bdb2-31b2cf11eeb7"],

Cell["", "Spacer",ExpressionUUID->"f8da9f16-bb7b-479e-8071-ffa26d66296f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"f3340101-ce33-427e-80dc-d41df97d2d3e"],

Cell[CellGroupData[{

Cell["\<\
Descriptive Statistics: Multivariate Measures and Visualization\
\>", "Section",
 CellChangeTimes->{{3.5377014908275223`*^9, 
  3.537701496336153*^9}},ExpressionUUID->"a816b2af-7e91-463b-8be8-\
bc1f83ae834d"],

Cell[TextData[{
 "This gives the marginal descriptive measures based on the first 4 moments, \
as well as the median and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "th"], TraditionalForm]],ExpressionUUID->
  "ac85e19f-365b-40ed-8eb1-aac5d137482f"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["90", "th"], TraditionalForm]],ExpressionUUID->
  "53db475c-8f00-4c59-bb17-63ed6d0c1727"],
 " percentiles for waiting durations and waiting time."
}], "Text",
 CellChangeTimes->{{3.497705549937003*^9, 3.4977055769857826`*^9}, {
   3.497706031889305*^9, 3.4977060477964363`*^9}, 3.4977093701475544`*^9, {
   3.497709404586377*^9, 
   3.4977094315561624`*^9}},ExpressionUUID->"e2ff106d-20f0-4f71-a377-\
2fd360294a6a"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"N", "[", "ofdata", "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"f", ",", 
     RowBox[{"{", 
      RowBox[{
      "Mean", ",", "Variance", ",", "Skewness", ",", "Kurtosis", ",", 
       "Median", ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".1"}], "]"}], "&"}], ",", 
       RowBox[{
        RowBox[{"Quantile", "[", 
         RowBox[{"#", ",", ".9"}], "]"}], "&"}]}], "}"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.497705451758217*^9, 3.4977055348265643`*^9}, {
  3.4977059668543096`*^9, 3.4977060106380816`*^9}, {3.4977093769134393`*^9, 
  3.497709402492546*^9}, {3.4977094340406327`*^9, 
  3.4977094364782267`*^9}},ExpressionUUID->"fa265a84-33c1-47f8-b400-\
fd78b94a415f"],

Cell["\<\
We could also obtain the correlation between duration and waiting time.\
\>", "MathCaption",
 CellChangeTimes->{{3.497705549937003*^9, 3.4977055769857826`*^9}, {
  3.497706031889305*^9, 3.4977060477964363`*^9}, {3.4977088526304226`*^9, 
  3.497708871537036*^9}},ExpressionUUID->"7ecd20a0-cf6e-4259-8b46-\
d81cfc45dd45"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Correlation", "[", "ofdata", "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.4977077101400537`*^9, 3.497707759408201*^9}, {
   3.4977078357714853`*^9, 3.4977078750391207`*^9}, {3.497708546692758*^9, 
   3.497708585957629*^9}, {3.4977087833009667`*^9, 3.4977087850197496`*^9}, 
   3.4977088280674515`*^9},ExpressionUUID->"c7681e90-9a09-49e0-999e-\
90e02a2aefb1"],

Cell["\<\
There are numerous ways to visualize the bivariate data, including pointwise \
plots, density projections, and histograms based on binning or kernel density \
estimation.\
\>", "MathCaption",
 CellChangeTimes->{3.5316667938565235`*^9, 
  3.537701511898324*^9},ExpressionUUID->"3beb209b-6308-485f-8a9e-\
d60184cc1687"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ListPlot", "[", "ofdata", "]"}], ",", 
       RowBox[{"DensityHistogram", "[", 
        RowBox[{"ofdata", ",", "20", ",", "\"\<PDF\>\""}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Histogram3D", "[", 
        RowBox[{"ofdata", ",", "20", ",", "\"\<PDF\>\""}], "]"}], ",", 
       RowBox[{"SmoothHistogram3D", "[", "ofdata", "]"}]}], "}"}]}], 
    "\[IndentingNewLine]", "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5316662700631495`*^9, 
  3.5316662717293158`*^9}},ExpressionUUID->"81f25eb9-4041-4aed-85aa-\
6a5a107b02cc"],

Cell["", "Spacer",ExpressionUUID->"7e361621-40c3-4e3e-9ed9-5071d6a69906"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"f2cd66ca-2fed-4ce8-80d6-0282ecf6d0c7"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Categorical Charts", "Section",
 CellChangeTimes->{
  3.537701525709445*^9},ExpressionUUID->"6a51ff76-49be-4004-bfeb-\
039f63d0eff5"],

Cell["\<\
We might want to decompose the data into categories\[LongDash]for instance, \
based on specific ranges of duration.\
\>", "Text",
 CellChangeTimes->{{3.497707490738196*^9, 3.497707542131452*^9}, 
   3.536498482718508*^9, {3.537701545652953*^9, 3.537701558119356*^9}, 
   3.537729947555607*^9},ExpressionUUID->"ea3e66ea-1394-4db0-bc20-\
4ce17f64aae8"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["BinCounts",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/BinCounts"]], "InlineFormula",ExpressionUUID->
  "45b0adcc-8b8b-4ff5-b8c9-5aa6283ee7ca"],
 " is used here to count the times ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]],ExpressionUUID->
  "7c0a044b-c959-4e0e-8dcd-28ce8de111df"],
 " such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "<", "2"}], TraditionalForm]],ExpressionUUID->
  "ade04c03-2fd0-4c64-af23-0fb1ffdbe4cf"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[LessEqual]", "t", "<", "3"}], TraditionalForm]],
  ExpressionUUID->"5fdd0cd5-4c75-463d-a572-c887a106da84"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "\[LessEqual]", "t", "<", "4"}], TraditionalForm]],
  ExpressionUUID->"cc2377cd-f382-48d3-8eb3-987d38599e07"],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "\[GreaterEqual]", "4"}], TraditionalForm]],ExpressionUUID->
  "2cc72766-630c-4724-ba34-abb3c6c4a54a"],
 ", respectively."
}], "MathCaption",ExpressionUUID->"e82b91ee-b1f7-4f7f-b4ff-dc64e90e1e57"],

Cell[BoxData[
 RowBox[{"bc", "=", 
  RowBox[{"BinCounts", "[", 
   RowBox[{
    RowBox[{"ofdata", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "3", ",", "4", ",", "10"}], "}"}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.497707097312764*^9, 3.4977072550386286`*^9}, {
  3.4977100657710257`*^9, 
  3.4977100695524445`*^9}},ExpressionUUID->"dc808cb5-9d23-4eb5-a6f0-\
8e30f6344940"],

Cell["\<\
The counts could then be visualized in a bar chart or a pie chart.\
\>", "MathCaption",
 CellChangeTimes->{{3.434987627934633*^9, 3.4349876422478657`*^9}, {
  3.4977076442773066`*^9, 
  3.497707664497092*^9}},ExpressionUUID->"1a988616-4454-4f8a-91ad-\
b2ce20ff206a"],

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"bc", ",", 
       RowBox[{"ChartStyle", "\[Rule]", "\"\<DarkRainbow\>\""}], ",", 
       RowBox[{"ChartLabels", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<t<2\>\"", ",", "\"\<2\[LessEqual]t<3\>\"", ",", 
          "\"\<3\[LessEqual]t<4\>\"", ",", "\"\<t\[GreaterEqual]4\>\""}], 
         "}"}]}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"BarChart", ",", "PieChart"}], "}"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input",Expressio\
nUUID->"fdb80f32-8050-4504-ae0f-4ea295caa02b"],

Cell["", "Spacer",ExpressionUUID->"3c5acff1-a887-4e42-a1b2-af63442995a2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"23566841-7bf5-4ab6-97d1-5d905da4e23e"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Data Transformation", "Section",
 CellChangeTimes->{
  3.5377015707900543`*^9},ExpressionUUID->"16016f43-94e7-4814-ba67-\
ba58d8406bbc"],

Cell[TextData[{
 "Built\[Hyphen]in smoothers include ",
 Cell[BoxData[
  ButtonBox["MovingAverage",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingAverage"]], "InlineFormula",ExpressionUUID->
  "d59c24b3-f2b5-455d-9858-294a55c697dd"],
 ", ",
 Cell[BoxData[
  ButtonBox["MovingMedian",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingMedian"]], "InlineFormula",ExpressionUUID->
  "e0189a72-30f8-4a16-ae62-e436dc8109ff"],
 ", and ",
 Cell[BoxData[
  ButtonBox["ExponentialMovingAverage",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ExponentialMovingAverage"]], "InlineFormula",
  ExpressionUUID->"de4a346e-fbf2-46ec-840f-54331f9d7245"],
 ". Data can be shifted and scaled using ",
 Cell[BoxData[
  ButtonBox["Standardize",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Standardize"]], "InlineFormula",ExpressionUUID->
  "3cd779d4-06ff-4f3c-a1c7-d3af3397c6e8"],
 ". Filters of particular interest for signals and image analysis are also \
included."
}], "Text",ExpressionUUID->"6ea9cbc7-d465-435a-859c-6210ae44ed9d"],

Cell["This gets and plots some historical Dow Jones data.", "MathCaption",
 CellChangeTimes->{{3.435077509556466*^9, 3.435077510322081*^9}, {
  3.4977113511411076`*^9, 
  3.4977113711420035`*^9}},ExpressionUUID->"d91b00b0-9dcf-4c16-9b4f-\
f27acf5bbb1d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dow", "=", 
   RowBox[{"FinancialData", "[", 
    RowBox[{"\"\<^DJI\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2010", ",", "1", ",", "1"}], "}"}], ",", 
       RowBox[{"{", " ", 
        RowBox[{"2011", ",", "1", ",", "1"}], "}"}]}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"DateListPlot", "[", "dow", "]"}]}], "Input",
 CellChangeTimes->{{3.497710118101495*^9, 3.4977102151839685`*^9}, {
   3.4977102768429813`*^9, 3.497710278811819*^9}, 3.497711390517872*^9, {
   3.5316666109242325`*^9, 3.5316666131974597`*^9}, {3.7258884067900286`*^9, 
   3.7258884190771656`*^9}},ExpressionUUID->"acd0d92d-b268-48ba-a5e8-\
f9e9431f3792"],

Cell["\<\
Here 25\[Hyphen]term moving averages and moving medians are computed and \
visualized against the original data.\
\>", "MathCaption",
 CellChangeTimes->{{3.4977113841894627`*^9, 3.4977114367699437`*^9}, {
   3.4977154507073517`*^9, 3.497715453066863*^9}, 
   3.537701585161858*^9},ExpressionUUID->"7665cd3f-db18-4312-a5ca-\
51bd03f5e035"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"movavgdata", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dow", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"13", ";;", 
          RowBox[{"-", "13"}]}], ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"MovingAverage", "[", 
       RowBox[{
        RowBox[{"dow", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "25"}], "]"}]}], 
     "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"movmeddata", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dow", "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"13", ";;", 
          RowBox[{"-", "13"}]}], ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"MovingMedian", "[", 
       RowBox[{
        RowBox[{"dow", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", "25"}], "]"}]}], 
     "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{"DateListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"dow", "[", 
      RowBox[{"[", 
       RowBox[{"13", ";;", 
        RowBox[{"-", "13"}]}], "]"}], "]"}], ",", "movavgdata", ",", 
     "movmeddata"}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"False", ",", "True", ",", "True"}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "Thick", ",", "Thick"}], "}"}]}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.497710282593239*^9, 3.4977103227669134`*^9}, {
  3.4977107435826397`*^9, 3.497710777990432*^9}, {3.4977108143983126`*^9, 
  3.4977108285864477`*^9}, {3.4977113792673674`*^9, 3.4977113994088945`*^9}, {
  3.497715291649604*^9, 3.497715309682123*^9}, {3.4977153686081457`*^9, 
  3.4977154360346317`*^9}},
 CellTags->
  "Data Smoothing",ExpressionUUID->"4ccca923-d719-4fb7-823a-a6795e0eb7ee"],

Cell["", "Spacer",ExpressionUUID->"3f24a27a-762b-419b-8bc9-0eb31443ab29"],

Cell["\<\
A complete set of financial visualization functions is also included, making \
it straightforward to built and work with financial charts.\
\>", "Text",
 CellChangeTimes->{{3.49771091401215*^9, 3.497710956654685*^9}, 
   3.4982347620415154`*^9, {3.5316666326794076`*^9, 
   3.5316666421103506`*^9}},ExpressionUUID->"1aa26e88-432b-4d8a-81b8-\
03c2eabed413"],

Cell[TextData[{
 "Note that ",
 Cell[BoxData[
  ButtonBox["MovingAverage",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingAverage"]], "InlineFormula",ExpressionUUID->
  "a5f841c9-43c2-43d2-bcbb-4c2a81c36451"],
 " and ",
 Cell[BoxData[
  ButtonBox["MovingMedian",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MovingMedian"]], "InlineFormula",ExpressionUUID->
  "2ed65ed7-31e8-4e65-83e2-f19a92fb6a73"],
 " reduce the length of the output list while ",
 ButtonBox["built\[Hyphen]in filter functions",
  BaseStyle->"Hyperlink",
  ButtonData->{"paclet:guide/LinearAndNonlinearFilters", None}],
 " operate in a manner that preserves data length."
}], "Text",
 CellChangeTimes->{{3.49771091401215*^9, 3.497710956654685*^9}, {
  3.4977154760994396`*^9, 3.497715560901199*^9}, {3.531668380568184*^9, 
  3.531668380572184*^9}},ExpressionUUID->"590a9f86-5b34-4ba3-92fe-\
c25d3141399f"],

Cell[TextData[{
 "Other smoothers and transformations can be constructed using functions such \
as ",
 Cell[BoxData[
  ButtonBox["ListCorrelate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListCorrelate"]], "InlineFormula",ExpressionUUID->
  "7894278f-9363-410f-85ba-223f75830c98"],
 " and ",
 Cell[BoxData[
  ButtonBox["ListConvolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListConvolve"]], "InlineFormula",ExpressionUUID->
  "36e1c273-d635-43f3-aea4-272cd1a3acc9"],
 ", and arithmetic and linear algebra functions."
}], "Text",
 CellChangeTimes->{{3.434991101694541*^9, 3.4349911038355494`*^9}, {
  3.4350777351473284`*^9, 
  3.435077738694158*^9}},ExpressionUUID->"27db7bc1-82e7-4404-83a9-\
cef2b5efb277"],

Cell["", "Spacer",ExpressionUUID->"bed54231-bbf7-42d0-8c10-bc8cd4eba8e1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"ee5dc777-72e3-4bf1-aeee-5a5b9b71e8a0"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Clustering Data", "Section",
 CellChangeTimes->{
  3.537701602411358*^9},ExpressionUUID->"22d0cfdc-01ab-46e4-a4e3-\
ab89b078ad99"],

Cell["\<\
Clustering of data is often used to separate data into groups, or to try to \
identify subgroups within a dataset.\
\>", "Text",
 CellChangeTimes->{
  3.537729975986679*^9},ExpressionUUID->"103f8813-0ef4-4aa7-ba95-\
4e8e643078e8"],

Cell[TextData[{
 "The main clustering function is ",
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula",ExpressionUUID->
  "db85f4f1-60de-4c44-8f6e-e9bda188877c"],
 ", which can be used on numeric, binary/Boolean, or string data; for a \
complete list of measures of distance, see the ",
 ButtonBox["Distance and Similarity Measures",
  BaseStyle->"Link",
  ButtonData->"paclet:guide/DistanceAndSimilarityMeasures"],
 " guide page. Used with ",
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula",ExpressionUUID->
  "2f32e0ec-2d4c-4fc8-b234-2a0a0c7fd101"],
 ", these define measures for separating data."
}], "Text",
 CellChangeTimes->{{3.4976312868456273`*^9, 
  3.497631291236449*^9}},ExpressionUUID->"3be2412d-0487-49d8-8be9-\
a068047b2b77"],

Cell["\<\
As an example, we will start with samples from 10 bivariate normal \
distributions stored in an Excel spreadsheet.\
\>", "MathCaption",
 CellChangeTimes->{{3.5316669128683853`*^9, 3.5316669358993855`*^9}, {
  3.531666987096386*^9, 
  3.5316669934833856`*^9}},ExpressionUUID->"f632802a-2204-4af1-8885-\
1b62ed4a08f7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"origclusters", "=", 
   RowBox[{"Import", "[", "\"\<NormalClusters.xls\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "origclusters", "]"}]}], "Input",
 CellChangeTimes->{{3.5316669554503856`*^9, 3.5316669661373854`*^9}, {
  3.531667012388386*^9, 3.5316670135563855`*^9}, {3.5316670588423853`*^9, 
  3.531667059657386*^9}},ExpressionUUID->"9123d777-a70d-4bd5-9482-\
31f28ab24a8f"],

Cell[TextData[{
 "Next we will mix up the elements of the original data so the data is not \
already grouped, and use ",
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula",ExpressionUUID->
  "77095ee2-1615-43af-9ce1-6f04c0e4439c"],
 " to identify clusters in the data."
}], "MathCaption",
 CellChangeTimes->{{3.53770161163426*^9, 
  3.53770161210674*^9}},ExpressionUUID->"84e18e24-5d5a-4718-ab45-\
bae9b466eae3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"newclusters", "=", 
   RowBox[{"BlockRandom", "[", 
    RowBox[{
     RowBox[{"SeedRandom", "[", "1", "]"}], ";", 
     RowBox[{"RandomSample", "[", 
      RowBox[{"Flatten", "[", 
       RowBox[{"origclusters", ",", "1"}], "]"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",ExpressionUUID->"adef17d4-f48b-40cf-8569-ee0c0c571e45"],

Cell[BoxData[
 RowBox[{
  RowBox[{"clusters", "=", 
   RowBox[{"FindClusters", "[", "newclusters", "]"}]}], ";"}]], "Input",Expres\
sionUUID->"d50ef126-9a99-4974-8da3-b1159f8155b8"],

Cell[TextData[{
 Cell[BoxData[
  ButtonBox["FindClusters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindClusters"]], "InlineFormula",ExpressionUUID->
  "6d2203de-c08a-4f08-99f5-012c0a6578a6"],
 " identifies 3 distinct clusters, which looks quite reasonable given the \
scatter of the data."
}], "MathCaption",ExpressionUUID->"87d6699d-9946-493a-953c-3118c2db0f36"],

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListPlot", "[", "origclusters", "]"}], ",", 
      RowBox[{"ListPlot", "[", "clusters", "]"}]}], "}"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", " ", "All"}], ",", 
   RowBox[{"FrameStyle", "\[Rule]", " ", "Thick"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input",Expressio\
nUUID->"9d199e33-a009-4ddb-a7fe-bed12365e432"],

Cell["", "Spacer",ExpressionUUID->"9c70bc57-4085-4d3f-9f57-b753e8dd638e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"b24daf8a-28db-4f16-8538-f65f451fe64f"],

Cell[CellGroupData[{

Cell["Descriptive Statistics: Cluster Hierarchies", "Section",
 CellChangeTimes->{
  3.537701623792327*^9},ExpressionUUID->"0bbc5936-0d9c-4216-92e5-\
5513d2302726"],

Cell[TextData[{
 "A cluster hierarchy can also be visualized using dendrogram plots. The ",
 ButtonBox["Hierarchical Clustering",
  BaseStyle->"Link",
  ButtonData->
   "paclet:HierarchicalClustering/guide/HierarchicalClusteringPackage"],
 " package is needed for this type of visualization."
}], "Text",ExpressionUUID->"d4df6709-7a05-4509-82fa-8fe933cfe6dc"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<HierarchicalClustering`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.434993341731686*^9, 
  3.434993345669816*^9}},ExpressionUUID->"09173a93-cb0b-41a0-b26b-\
0597da0740b9"],

Cell["Here is some example text, split into string elements.", "MathCaption",ExpressionUUID->"84b8094c-4529-4f53-8957-35a8fe9453e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"textdata", "=", 
   RowBox[{
   "StringSplit", "[", 
    "\"\<This seminar will give a broad overview of statistics in \
Mathematica. Statistics functions and other technologies, such as \
import/export capabilities and visualization functions, as they relate to \
statistical computation will be discussed.\>\"", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.442137335843274*^9, {3.4976312144986362`*^9, 
   3.4976312153893013`*^9}},ExpressionUUID->"48002c26-4a15-4347-a9eb-\
15be8c7e6d69"],

Cell["\<\
The following generates a dendrogram, labeling the leaves with the string \
elements they represent.\
\>", "MathCaption",
 CellChangeTimes->{3.437936802972034*^9, 
  3.537701644339539*^9},ExpressionUUID->"5a99883c-c4c0-4795-a9af-\
8e4e1d127c9a"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"DendrogramPlot", "[", 
    RowBox[{"textdata", ",", 
     RowBox[{"LeafLabels", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"#", "&"}], ")"}]}], ",", 
     RowBox[{"Orientation", "\[Rule]", "Left"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.442050362811325*^9, 3.442050373857665*^9}, {
  3.442050452437312*^9, 
  3.442050468130804*^9}},ExpressionUUID->"c64fa7c7-2a8e-40b6-8b7d-\
d5542ad69137"],

Cell["", "Spacer",ExpressionUUID->"320a4050-e8e2-43d0-9aa6-eb67f3a64ade"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->
  "SlideShowHeader",ExpressionUUID->"2253df48-8f51-4878-ae48-eb7c87bdb439"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->
  True,ExpressionUUID->"5440d2cb-9ffc-4d6d-a4ee-6df4a5006777"],

Cell[CellGroupData[{

Cell["StyleTable", "MoreExamplesSection",ExpressionUUID->"486a75d3-8410-4ca3-93f8-778d18c00ac4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"StyleTable", "[", 
   RowBox[{"tbl_Style", ",", 
    RowBox[{"rools_List", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"tbl", "/.", 
   RowBox[{
    RowBox[{"Style", "[", 
     RowBox[{"x_", ",", "\"\<DialogStyle\>\""}], "]"}], "\[RuleDelayed]", 
    RowBox[{"Style", "[", 
     RowBox[{"x", ",", "\"\<DialogStyle\>\"", ",", 
      RowBox[{"Sequence", "@@", "rools"}]}], "]"}]}]}]}]], "Input",ExpressionU\
UID->"06ccb162-eda6-4f30-802d-1cf3ec090c09"]
}, Closed]],

Cell[CellGroupData[{

Cell["Overview Mouseover", "MoreExamplesSection",
 CellChangeTimes->{{3.49896919710295*^9, 
  3.498969204966164*^9}},ExpressionUUID->"14b97638-348c-4be1-9edd-\
abb8882ee1d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"m8red", "[", "a_", "]"}], ":=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.811765", ",", "0.117647", ",", "0.145098", ",", "a"}], "]"}]}],
   ";"}]], "Input",ExpressionUUID->"0f5d1a47-5c97-44d6-a314-839476384226"],

Cell[BoxData[
 RowBox[{
  RowBox[{"OverviewMouseover", "[", 
   RowBox[{"header_", ",", "subs_"}], "]"}], ":=", 
  RowBox[{"CellPrint", "@", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"BoxData", "[", 
      RowBox[{"ToBoxes", "@", 
       RowBox[{"Mouseover", "[", 
        RowBox[{
         RowBox[{"Framed", "[", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"header", ",", "\"\<OverviewSection\>\""}], "]"}], ",", 
           RowBox[{"FrameMargins", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"15", ",", "15"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
           RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
           RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], ",", 
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Evaluate", "@", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"subs", "\[Equal]", "\"\<\>\""}], ",", 
            RowBox[{"Framed", "[", 
             RowBox[{
              RowBox[{"Style", "[", 
               RowBox[{
               "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
               "]"}], ",", 
              RowBox[{"FrameMargins", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"15", ",", "15"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
              RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
              RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
              RowBox[{"Background", "\[Rule]", 
               RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{
                  "header", ",", "\"\<OverviewSection\>\"", ",", "White"}], 
                  "]"}], ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", "None"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}]}], "]"}], ",", 
               "\"\< \[RightGuillemet] \>\"", ",", 
               RowBox[{"Framed", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"subs", ",", "\"\<OverviewSection\>\""}], "]"}], 
                 ",", 
                 RowBox[{"FrameMargins", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"15", ",", "15"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"5", ",", "5"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"FrameStyle", "\[Rule]", 
                  RowBox[{"m8red", "[", "1", "]"}]}], ",", 
                 RowBox[{"BoxFrame", "\[Rule]", "2"}], ",", 
                 RowBox[{"RoundingRadius", "\[Rule]", "5"}], ",", 
                 RowBox[{"Background", "\[Rule]", "White"}]}], "]"}]}], "}"}],
              "]"}]}], "]"}]}]}], "]"}]}], "]"}], ",", 
     "\"\<OverviewSection\>\""}], "]"}]}]}]], "Input",ExpressionUUID->\
"ff2bf442-cefa-4f05-aa13-c2a73b1e3b22"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MapThread", "[", 
     RowBox[{"OverviewMouseover", ",", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Descriptive\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"and\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"Exploratory\",FontWeight->\"Bold\"]\
\)\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"S\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\"tatistics\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<descriptive measures and charts, smoothing, transformations, \
clustering, visualization\>\""}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Statistical\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"D\",FontWeight->\"Bold\
\"]\)\!\(\*StyleBox[\"istributions\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<parametric and nonparametric distributions, properties of \
distributions, random numbers, parameter estimation, visualization\>\""}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Hypothesis\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"T\",FontWeight->\"Bold\
\"]\)\!\(\*StyleBox[\"esting\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<tests of distributional goodness of fit, tests of location \
and scale\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<\!\(\*StyleBox[\"Model\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\
\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"F\",FontWeight->\"Bold\"]\)\!\(\
\*StyleBox[\"itting\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\" \
\",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"and\",FontWeight->\"Bold\"]\)\!\(\*\
StyleBox[\" \",FontWeight->\"Bold\"]\)\!\(\*StyleBox[\"A\",FontWeight->\"Bold\
\"]\)\!\(\*StyleBox[\"nalysis\",FontWeight->\"Bold\"]\)\>\"", ",", 
           "\"\<linear regression, nonlinear regression, generalized linear \
models including logit and probit, ANOVA\>\""}], "}"}]}], "}"}], "]"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]"}]], "Input",ExpressionUUID->"ecd462c3-6ad2-4102-9e88-\
dffe40b10efe"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{"OverviewMouseover", ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<ProbabilityDistribution\>\"", ",", 
          "\"\<defined by a PDF or other characteristic and the support of \
the distribution\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<TransformedDistribution\>\"", ",", 
          "\"\<distribution of a functional transformation of one or more \
random variates\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<TruncatedDistribution\>\"", ",", 
          "\"\<distribution with support truncated above or below and \
rescaled to have probability 1\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<CensoredDistribution\>\"", ",", 
          "\"\<distribution with upper and lower tail probabilities \
concentrated at defined censoring points\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<OrderDistribution\>\"", ",", 
          "\"\<distribution of the \
\!\(TraditionalForm\`\*SuperscriptBox[\(k\), \(th\)]\) order statistic for a \
sample of size \!\(TraditionalForm\`n\)\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<MixtureDistribution\>\"", ",", 
          "\"\<component mixture distribution\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<ParameterMixtureDistribution\>\"", ",", 
          "\"\<parametric mixture distribution\>\""}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<ProductDistribution\>\"", ",", 
          "\"\<multivariate distribution with independent components defined \
by distributions of the components\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<MarginalDistribution\>\"", ",", 
          "\"\<lower dimensional distribution obtained from a multivariate \
distribution\>\""}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<CopulaDistribution\>\"", ",", 
          "\"\<multivariate distribution defined by marginal distributions \
and a kernel that defines how they are combined\>\""}], "}"}]}], 
       "\[IndentingNewLine]", "}"}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", "*)"}]], "Input",ExpressionUUID->"cc9469b3-a5ff-4916-\
9388-8d590be7e5ba"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{"OverviewMouseover", ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<LinearModelFit\>\"", ",", "\"\<linear regression\>\""}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<LogitModelFit\>\"", ",", "\"\<logistic regression\>\""}], "}"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"\"\<ProbitModelFit\>\"", ",", "\"\<probit regression\>\""}],
          "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<GeneralizedLinearModelFit\>\"", ",", 
          "\"\<generalized linear models with specified distributional \
structures and links\>\""}], "}"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
    "]"}], ";"}], "\[IndentingNewLine]", "*)"}]], "Input",ExpressionUUID->\
"57aa8025-bc00-4cfa-a031-7a311d8c0c94"]
}, Closed]],

Cell[CellGroupData[{

Cell["FillToLinePlot", "MoreExamplesSection",ExpressionUUID->"0f7cd00a-10b5-45ff-b3f3-8ec085090f44"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FillToLinePlot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"f1_", ",", "lab1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"f2_", ",", "lab2_"}], "}"}], ",", "val_", ",", 
    RowBox[{"{", 
     RowBox[{"var_", ",", "min_", ",", "max_"}], "}"}]}], "]"}], ":=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Max", "[", 
       RowBox[{"val", ",", "f1"}], "]"}], ",", 
      RowBox[{"Max", "[", 
       RowBox[{"val", ",", "f2"}], "]"}], ",", 
      RowBox[{"Tooltip", "[", 
       RowBox[{"f1", ",", "lab1"}], "]"}], ",", 
      RowBox[{"Tooltip", "[", 
       RowBox[{"f2", ",", "lab2"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "min", ",", "max"}], "}"}], ",", 
    RowBox[{"Epilog", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Thick", ",", "Dashed", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"min", ",", "val"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"max", ",", "val"}], "}"}]}], "}"}], "]"}]}], "}"}], 
      "}"}]}], ",", 
    RowBox[{"Filling", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "val"}], ",", 
       RowBox[{"2", "\[Rule]", "val"}]}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ColorData", "[", 
        RowBox[{"1", ",", "1"}], "]"}], ",", 
       RowBox[{"ColorData", "[", 
        RowBox[{"1", ",", "2"}], "]"}]}], "}"}]}]}], "]"}]}]], "Input",Express\
ionUUID->"69c66340-c09a-4b30-bf9e-124d9e2a0f6a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Graphics Options", "MoreExamplesSection",
 CellChangeTimes->{
  3.5377016595272408`*^9},ExpressionUUID->"b3a66b71-d37d-40dc-9daa-\
54716681c399"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListPlot", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PlotStyle", "\[Rule]", " ", 
       RowBox[{"PointSize", "[", "Medium", "]"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", " ", "Large"}]}], "}"}]}], "]"}], 
  ";"}]], "Input",ExpressionUUID->"7f8b45b9-aa73-4979-b5b9-9e6e3bd3bbe2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ListPointPlot3D", ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}], ";"}]], "Input",Exp\
ressionUUID->"e83f65c2-f7d4-4029-b730-d267b2b153a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"DiscretePlot", ",", 
    RowBox[{"PlotStyle", "\[Rule]", " ", 
     RowBox[{"PointSize", "[", "Medium", "]"}]}]}], "]"}], ";"}]], "Input",Exp\
ressionUUID->"17631d04-0f1a-495b-a3aa-935465ca7fd7"]
}, Closed]],

Cell[CellGroupData[{

Cell["Load Packages", "MoreExamplesSection",
 CellChangeTimes->{
  3.5377016634732656`*^9},ExpressionUUID->"b69406d0-c496-43cb-aaa7-\
82b262cfa25e"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<HierarchicalClustering`\>\"", "]"}]], "Input",Expr\
essionUUID->"b0aa7e44-0d58-40a5-9605-03183df85951"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ANOVA`\>\"", "]"}]], "Input",ExpressionUUID->"a5a60583-a47f-4e60-bd98-4227c96a3294"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set Working Directory", "MoreExamplesSection",
 CellChangeTimes->{{3.537701668265525*^9, 
  3.5377016730257473`*^9}},ExpressionUUID->"8358552f-6a06-4f69-afd7-\
0ba3607fd216"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<Data\>\""}], "}"}], 
   "]"}], "]"}]], "Input",ExpressionUUID->"88af7897-baa5-4452-a9ab-\
6b3f5d1bce86"],

Cell[BoxData["\<\"E:\\\\Amruta\\\\Wolfram Internship\\\\Training \
Folders\\\\DAT012\\\\Data\"\>"], "Output",
 CellChangeTimes->{
  3.72588771310176*^9, 3.7258885004492865`*^9, {3.725888594130088*^9, 
   3.7258886014819593`*^9}},ExpressionUUID->"fb78cfae-bc13-4640-9e29-\
c31f66b206b5"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lastly", "MoreExamplesSection",ExpressionUUID->"92bb332a-5e14-48c5-acff-68ce8b9f06b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Line", "=", "0"}], ";"}]], "Input",ExpressionUUID->"290340a2-5795-4962-bba8-f9f0024989b4"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
ScreenStyleEnvironment->"SlideShow",
WindowToolbars->{},
WindowSize->{958, 988},
WindowMargins->{{Automatic, -7}, {Automatic, 0}},
WindowTitle->"Statistics: Descriptive and Exploratory",
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefinitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "Presentation"], 
             CellMargins -> {{100, 100}, {10, 150}}, FontSize -> 54], 
            Cell[
             StyleData["LargeChapter", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{84, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontWeight -> "Plain", FontColor -> 
             RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             CellMargins -> {{88, 60}, {20, 12}}, FontWeight -> 
             "Plain", $CellContext`WholeCellGroupOpener -> True]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {
              LimitsPositioning -> True}, $CellContext`StripStyleOnPaste -> 
             True], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               1.75 Inherited, 1.75 Inherited}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {1.5 Inherited, 1.5 Inherited}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {1.5 Inherited, 1.5 Inherited}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"]], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 0}}, FontFamily -> "Helvetica", 
             FontSize -> 17]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 22, FontWeight -> Plain, FontColor -> 
             RGBColor[
              0.811765, 0.117647, 
               0.145098], $CellContext`ReturnCreatesNewCell -> True]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Editorial"], ShowCellBracket -> Automatic, 
             CellMargins -> {{24, 10}, {6, 6}}, 
             CellBracketOptions -> {
              "Color" -> RGBColor[0.786999, 0.0386053, 0.0571756]}, 
             CellFrameLabels -> {{
                Cell[
                 TextData[{"Edit:"}], FontFamily -> "Helvetica", FontSize -> 
                 16, FontWeight -> "Bold", CellBaseline -> Baseline], None}, {
               None, None}}, DefaultNewInlineCellStyle -> "None", Hyphenation -> 
             True, LineSpacing -> {1, 3}, LanguageCategory -> 
             "NaturalLanguage", FontFamily -> "Helvetica", FontSize -> 19, 
             FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Editorial", "SlideShow"], 
             CellMargins -> {{Inherited, Inherited}, {0, 0}}, 
             CellElementSpacings -> {
              "CellMinHeight" -> 1, "ClosedCellHeight" -> 0}, CellOpen -> 
             False]}, Closed]], 
         Cell[
          StyleData["DialogStyle"], FontSize -> 17], 
         Cell[
          StyleData["TooltipLabel"], CellFrame -> 1., CellFrameMargins :> 
          CurrentValue["TooltipFrameMargins"], CellFrameColor :> 
          CurrentValue[{"SystemColor", "TooltipFrame"}], TextAlignment -> 
          Left, TextJustification -> 0., ShowStringCharacters -> False, 
          FontFamily :> CurrentValue["TooltipFontFamily"], FontSize :> 
          CurrentValue["TooltipFontSize"], FontWeight -> "Plain", FontSlant -> 
          "Plain", Magnification -> 1.5, FontColor :> 
          CurrentValue[{"SystemColor", "TooltipText"}], FontOpacity -> 1., 
          Background :> CurrentValue[{"SystemColor", "Tooltip"}]]}, Open]]}, 
     Open]]}, Visible -> False, FrontEndVersion -> 
  "11.2 for Microsoft Windows (64-bit) (September 10, 2017)", 
  StyleDefinitions -> "StylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[632, 23, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"7bbb7a7c-0171-40a9-97fb-721bb3b1018f",
   CellTags->"SlideShowHeader"],
  Cell[1559, 52, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"9d3dd028-0f1c-446d-bc3b-32e6c2931ca6",
   CellTags->"SlideShowHeader"],
  Cell[2878, 87, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"da745353-0285-4251-b99a-c0e3c16d37c5",
   CellTags->"SlideShowHeader"],
  Cell[7638, 240, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"dce59320-bb66-4638-af68-f62f153f8038",
   CellTags->"SlideShowHeader"],
  Cell[12652, 387, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"f3340101-ce33-427e-80dc-d41df97d2d3e",
   CellTags->"SlideShowHeader"],
  Cell[16541, 498, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"f2cd66ca-2fed-4ce8-80d6-0282ecf6d0c7",
   CellTags->"SlideShowHeader"],
  Cell[19916, 602, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"23566841-7bf5-4ab6-97d1-5d905da4e23e",
   CellTags->"SlideShowHeader"],
  Cell[26658, 795, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"ee5dc777-72e3-4bf1-aeee-5a5b9b71e8a0",
   CellTags->"SlideShowHeader"],
  Cell[30885, 918, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"b24daf8a-28db-4f16-8538-f65f451fe64f",
   CellTags->"SlideShowHeader"],
  Cell[33351, 989, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"2253df48-8f51-4878-ae48-eb7c87bdb439",
   CellTags->"SlideShowHeader"]},
 "Data Smoothing"->{
  Cell[22588, 676, 1884, 55, 182, "Input",ExpressionUUID->"4ccca923-d719-4fb7-823a-a6795e0eb7ee",
   CellTags->"Data Smoothing"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 83955, 2168},
 {"Data Smoothing", 85409, 2189}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[632, 23, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"7bbb7a7c-0171-40a9-97fb-721bb3b1018f",
 CellTags->"SlideShowHeader"],
Cell[757, 27, 337, 8, 332, "Title",ExpressionUUID->"902b3e54-4904-48d6-a79c-b23ffc4007fb"],
Cell[1097, 37, 425, 10, 229, "Subsubtitle",ExpressionUUID->"5d034da4-9c57-4d6c-b752-85b2da6242d3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1559, 52, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"9d3dd028-0f1c-446d-bc3b-32e6c2931ca6",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[1706, 58, 145, 3, 99, "Section",ExpressionUUID->"48dd37a3-25db-46d0-b4b3-027cf5ac859b"],
Cell[1854, 63, 899, 16, 203, "Text",ExpressionUUID->"19e5e05c-4789-4621-a2cf-bea01a290674"],
Cell[2756, 81, 73, 0, 23, "Spacer",ExpressionUUID->"97ebb87d-adaa-43fa-8398-6d6d97f68d8a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2878, 87, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"da745353-0285-4251-b99a-c0e3c16d37c5",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3025, 93, 161, 3, 99, "Section",ExpressionUUID->"7fb390d5-19bd-4c5d-b236-ce1ec711fd5c"],
Cell[3189, 98, 162, 3, 48, "Text",ExpressionUUID->"640d022e-deff-4b27-93a4-8cf21a708f89"],
Cell[3354, 103, 73, 0, 23, "Spacer",ExpressionUUID->"58523f17-7726-4c25-890c-c363d71c0109"],
Cell[CellGroupData[{
Cell[3452, 107, 171, 3, 39, "Subsubsection",ExpressionUUID->"91ea43bf-4d28-4715-8575-fa5a9eac06b6"],
Cell[3626, 112, 653, 18, 81, "Text",ExpressionUUID->"67347638-c377-40f5-b0fd-759034df9cb1"],
Cell[4282, 132, 1425, 42, 83, "Text",ExpressionUUID->"6e3845d1-e09d-411c-90e3-ef689efb0107"],
Cell[5710, 176, 536, 14, 102, "MathCaption",ExpressionUUID->"69ab8571-ca44-471e-93a7-7404774bfeda"],
Cell[6249, 192, 336, 8, 41, "Input",ExpressionUUID->"c17d46ac-4318-4e49-a228-b719b0b93de1"],
Cell[6588, 202, 73, 0, 23, "Spacer",ExpressionUUID->"7ed7cfe1-aab4-40bf-a84a-46c3facfd2ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6698, 207, 89, 0, 39, "Subsubsection",ExpressionUUID->"8e0a8fcf-0e15-4a89-b8ab-f3ec6e428fad"],
Cell[6790, 209, 711, 22, 110, "Text",ExpressionUUID->"ad94b782-c7bc-4892-a3ad-7d425f3a708e"],
Cell[7504, 233, 73, 0, 23, "Spacer",ExpressionUUID->"805c74b0-311d-4c02-a493-07f79a3cf5b5"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[7638, 240, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"dce59320-bb66-4638-af68-f62f153f8038",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[7785, 246, 96, 0, 99, "Section",ExpressionUUID->"bc74e9d2-6692-401f-a846-4a1935d66117"],
Cell[7884, 248, 549, 12, 79, "Text",ExpressionUUID->"eac96ee6-b4de-4455-9613-a794b5a5fc41"],
Cell[8436, 262, 192, 3, 98, "MathCaption",ExpressionUUID->"cc156231-1c54-4994-9da5-e6cc0927083e"],
Cell[8631, 267, 286, 7, 41, "Input",ExpressionUUID->"efb2e7c5-4d6b-464d-9779-1b568b16f867"],
Cell[8920, 276, 653, 17, 98, "MathCaption",ExpressionUUID->"e2d4e11b-2ae3-46bd-a489-2353c7aac759"],
Cell[9576, 295, 1025, 29, 98, "Input",ExpressionUUID->"1f15dca5-9615-4746-8358-d1fea3eaf827"],
Cell[10604, 326, 73, 0, 23, "Spacer",ExpressionUUID->"7b32e463-b125-41a2-bc92-b8c3c0415ae8"],
Cell[10680, 328, 342, 7, 79, "Text",ExpressionUUID->"a3360e80-2f43-4f94-8cde-fb8c65950d98"],
Cell[11025, 337, 202, 3, 98, "MathCaption",ExpressionUUID->"2c29923b-6f2e-4ccb-8be9-5662b0648912"],
Cell[11230, 342, 857, 24, 70, "Input",ExpressionUUID->"290348f2-e20e-43f2-ada4-1643f2d31667"],
Cell[12090, 368, 73, 0, 23, "Spacer",ExpressionUUID->"5ab6379e-f5ac-40f2-9bc6-b1c8a35b7af2"],
Cell[12166, 370, 361, 9, 79, "Text",ExpressionUUID->"244797de-55a7-4098-bdb2-31b2cf11eeb7"],
Cell[12530, 381, 73, 0, 23, "Spacer",ExpressionUUID->"f8da9f16-bb7b-479e-8071-ffa26d66296f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[12652, 387, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"f3340101-ce33-427e-80dc-d41df97d2d3e",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[12799, 393, 218, 5, 148, "Section",ExpressionUUID->"a816b2af-7e91-463b-8be8-bc1f83ae834d"],
Cell[13020, 400, 728, 18, 79, "Text",ExpressionUUID->"e2ff106d-20f0-4f71-a377-2fd360294a6a"],
Cell[13751, 420, 816, 22, 70, "Input",ExpressionUUID->"fa265a84-33c1-47f8-b400-fd78b94a415f"],
Cell[14570, 444, 329, 6, 67, "MathCaption",ExpressionUUID->"7ecd20a0-cf6e-4259-8b46-d81cfc45dd45"],
Cell[14902, 452, 409, 7, 41, "Input",ExpressionUUID->"c7681e90-9a09-49e0-999e-90e02a2aefb1"],
Cell[15314, 461, 327, 7, 98, "MathCaption",ExpressionUUID->"3beb209b-6308-485f-8a9e-d60184cc1687"],
Cell[15644, 470, 772, 20, 126, "Input",ExpressionUUID->"81f25eb9-4041-4aed-85aa-6a5a107b02cc"],
Cell[16419, 492, 73, 0, 23, "Spacer",ExpressionUUID->"7e361621-40c3-4e3e-9ed9-5071d6a69906"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16541, 498, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"f2cd66ca-2fed-4ce8-80d6-0282ecf6d0c7",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[16688, 504, 163, 3, 99, "Section",ExpressionUUID->"6a51ff76-49be-4004-bfeb-039f63d0eff5"],
Cell[16854, 509, 360, 7, 79, "Text",ExpressionUUID->"ea3e66ea-1394-4db0-bc20-4ce17f64aae8"],
Cell[17217, 518, 1058, 31, 100, "MathCaption",ExpressionUUID->"e82b91ee-b1f7-4f7f-b4ff-dc64e90e1e57"],
Cell[18278, 551, 494, 14, 41, "Input",ExpressionUUID->"dc808cb5-9d23-4eb5-a6f0-8e30f6344940"],
Cell[18775, 567, 276, 6, 67, "MathCaption",ExpressionUUID->"1a988616-4454-4f8a-91ad-b2ce20ff206a"],
Cell[19054, 575, 737, 19, 98, "Input",ExpressionUUID->"fdb80f32-8050-4504-ae0f-4ea295caa02b"],
Cell[19794, 596, 73, 0, 23, "Spacer",ExpressionUUID->"3c5acff1-a887-4e42-a1b2-af63442995a2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19916, 602, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"23566841-7bf5-4ab6-97d1-5d905da4e23e",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[20063, 608, 166, 3, 99, "Section",ExpressionUUID->"16016f43-94e7-4814-ba67-ba58d8406bbc"],
Cell[20232, 613, 1036, 27, 114, "Text",ExpressionUUID->"6ea9cbc7-d465-435a-859c-6210ae44ed9d"],
Cell[21271, 642, 253, 4, 67, "MathCaption",ExpressionUUID->"d91b00b0-9dcf-4c16-9b4f-f27acf5bbb1d"],
Cell[21527, 648, 707, 17, 70, "Input",ExpressionUUID->"acd0d92d-b268-48ba-a5e8-f9e9431f3792"],
Cell[22237, 667, 348, 7, 98, "MathCaption",ExpressionUUID->"7665cd3f-db18-4312-a5ca-51bd03f5e035"],
Cell[22588, 676, 1884, 55, 182, "Input",ExpressionUUID->"4ccca923-d719-4fb7-823a-a6795e0eb7ee",
 CellTags->"Data Smoothing"],
Cell[24475, 733, 73, 0, 23, "Spacer",ExpressionUUID->"3f24a27a-762b-419b-8bc9-0eb31443ab29"],
Cell[24551, 735, 366, 7, 79, "Text",ExpressionUUID->"1aa26e88-432b-4d8a-81b8-03c2eabed413"],
Cell[24920, 744, 886, 22, 81, "Text",ExpressionUUID->"590a9f86-5b34-4ba3-92fe-c25d3141399f"],
Cell[25809, 768, 724, 19, 81, "Text",ExpressionUUID->"27db7bc1-82e7-4404-83a9-cef2b5efb277"],
Cell[26536, 789, 73, 0, 23, "Spacer",ExpressionUUID->"bed54231-bbf7-42d0-8c10-bc8cd4eba8e1"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26658, 795, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"ee5dc777-72e3-4bf1-aeee-5a5b9b71e8a0",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[26805, 801, 160, 3, 99, "Section",ExpressionUUID->"22d0cfdc-01ab-46e4-a4e3-ab89b078ad99"],
Cell[26968, 806, 240, 6, 79, "Text",ExpressionUUID->"103f8813-0ef4-4aa7-ba95-4e8e643078e8"],
Cell[27211, 814, 891, 22, 145, "Text",ExpressionUUID->"3be2412d-0487-49d8-8be9-a068047b2b77"],
Cell[28105, 838, 326, 7, 98, "MathCaption",ExpressionUUID->"f632802a-2204-4af1-8885-1b62ed4a08f7"],
Cell[28434, 847, 442, 9, 70, "Input",ExpressionUUID->"9123d777-a70d-4bd5-9482-31f28ab24a8f"],
Cell[28879, 858, 486, 12, 100, "MathCaption",ExpressionUUID->"84e18e24-5d5a-4718-ab45-bae9b466eae3"],
Cell[29368, 872, 358, 9, 70, "Input",ExpressionUUID->"adef17d4-f48b-40cf-8569-ee0c0c571e45"],
Cell[29729, 883, 181, 4, 41, "Input",ExpressionUUID->"d50ef126-9a99-4974-8da3-b1159f8155b8"],
Cell[29913, 889, 372, 8, 100, "MathCaption",ExpressionUUID->"87d6699d-9946-493a-953c-3118c2db0f36"],
Cell[30288, 899, 472, 11, 70, "Input",ExpressionUUID->"9d199e33-a009-4ddb-a7fe-bed12365e432"],
Cell[30763, 912, 73, 0, 23, "Spacer",ExpressionUUID->"9c70bc57-4085-4d3f-9f57-b753e8dd638e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30885, 918, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"b24daf8a-28db-4f16-8538-f65f451fe64f",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[31032, 924, 164, 3, 99, "Section",ExpressionUUID->"0bbc5936-0d9c-4216-92e5-5513d2302726"],
Cell[31199, 929, 359, 7, 79, "Text",ExpressionUUID->"d4df6709-7a05-4509-82fa-8fe933cfe6dc"],
Cell[31561, 938, 214, 4, 41, "Input",ExpressionUUID->"09173a93-cb0b-41a0-b26b-0597da0740b9"],
Cell[31778, 944, 132, 0, 67, "MathCaption",ExpressionUUID->"84b8094c-4529-4f53-8957-35a8fe9453e8"],
Cell[31913, 946, 530, 12, 154, "Input",ExpressionUUID->"48002c26-4a15-4347-a9eb-15be8c7e6d69"],
Cell[32446, 960, 255, 6, 98, "MathCaption",ExpressionUUID->"5a99883c-c4c0-4795-a9af-8e4e1d127c9a"],
Cell[32704, 968, 522, 13, 70, "Input",ExpressionUUID->"c64fa7c7-2a8e-40b6-8b7d-d5542ad69137"],
Cell[33229, 983, 73, 0, 23, "Spacer",ExpressionUUID->"320a4050-e8e2-43d0-9aa6-eb67f3a64ade"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33351, 989, 122, 2, 1, "SlideShowNavigationBar",ExpressionUUID->"2253df48-8f51-4878-ae48-eb7c87bdb439",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[33498, 995, 119, 2, 99, "Section",ExpressionUUID->"5440d2cb-9ffc-4d6d-a4ee-6df4a5006777",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[33642, 1001, 96, 0, 59, "MoreExamplesSection",ExpressionUUID->"486a75d3-8410-4ca3-93f8-778d18c00ac4"],
Cell[33741, 1003, 485, 12, 70, "Input",ExpressionUUID->"06ccb162-eda6-4f30-802d-1cf3ec090c09"]
}, Closed]],
Cell[CellGroupData[{
Cell[34263, 1020, 174, 3, 51, "MoreExamplesSection",ExpressionUUID->"14b97638-348c-4be1-9edd-abb8882ee1d4"],
Cell[34440, 1025, 262, 6, 70, "Input",ExpressionUUID->"0f5d1a47-5c97-44d6-a314-839476384226"],
Cell[34705, 1033, 3857, 88, 70, "Input",ExpressionUUID->"ff2bf442-cefa-4f05-aa13-c2a73b1e3b22"],
Cell[38565, 1123, 2441, 48, 70, "Input",ExpressionUUID->"ecd462c3-6ad2-4102-9e88-dffe40b10efe"],
Cell[41009, 1173, 2690, 63, 70, "Input",ExpressionUUID->"cc9469b3-a5ff-4916-9388-8d590be7e5ba"],
Cell[43702, 1238, 1033, 24, 70, "Input",ExpressionUUID->"57aa8025-bc00-4cfa-a031-7a311d8c0c94"]
}, Closed]],
Cell[CellGroupData[{
Cell[44772, 1267, 100, 0, 51, "MoreExamplesSection",ExpressionUUID->"0f7cd00a-10b5-45ff-b3f3-8ec085090f44"],
Cell[44875, 1269, 1655, 48, 70, "Input",ExpressionUUID->"69c66340-c09a-4b30-bf9e-124d9e2a0f6a"]
}, Closed]],
Cell[CellGroupData[{
Cell[46567, 1322, 151, 3, 51, "MoreExamplesSection",ExpressionUUID->"b3a66b71-d37d-40dc-9daa-54716681c399"],
Cell[46721, 1327, 363, 9, 70, "Input",ExpressionUUID->"7f8b45b9-aa73-4979-b5b9-9e6e3bd3bbe2"],
Cell[47087, 1338, 264, 6, 70, "Input",ExpressionUUID->"e83f65c2-f7d4-4029-b730-d267b2b153a1"],
Cell[47354, 1346, 261, 6, 70, "Input",ExpressionUUID->"17631d04-0f1a-495b-a3aa-935465ca7fd7"]
}, Closed]],
Cell[CellGroupData[{
Cell[47652, 1357, 148, 3, 51, "MoreExamplesSection",ExpressionUUID->"b69406d0-c496-43cb-aaa7-82b262cfa25e"],
Cell[47803, 1362, 145, 2, 70, "Input",ExpressionUUID->"b0aa7e44-0d58-40a5-9605-03183df85951"],
Cell[47951, 1366, 126, 1, 70, "Input",ExpressionUUID->"a5a60583-a47f-4e60-bd98-4227c96a3294"]
}, Closed]],
Cell[CellGroupData[{
Cell[48114, 1372, 180, 3, 51, "MoreExamplesSection",ExpressionUUID->"8358552f-6a06-4f69-afd7-0ba3607fd216"],
Cell[CellGroupData[{
Cell[48319, 1379, 267, 7, 41, "Input",ExpressionUUID->"88af7897-baa5-4452-a9ab-6b3f5d1bce86"],
Cell[48589, 1388, 286, 5, 70, "Output",ExpressionUUID->"fb78cfae-bc13-4640-9e29-c31f66b206b5"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[48924, 1399, 92, 0, 51, "MoreExamplesSection",ExpressionUUID->"92bb332a-5e14-48c5-acff-68ce8b9f06b2"],
Cell[49019, 1401, 126, 2, 70, "Input",ExpressionUUID->"290340a2-5795-4962-bba8-f9f0024989b4"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

